******
passwd
******

.. image:: https://github.com/bsoyka/passwd/workflows/Testing%20with%20pytest/badge.svg?event=push
   :target: https://github.com/bsoyka/passwd/actions
   :alt: Testing with pytest
.. image:: https://img.shields.io/badge/version-1.1.1-orange
   :target: https://github.com/bsoyka/passwd/releases/tag/v1.1.1
   :alt: Version 1.1.1
.. image:: https://img.shields.io/pypi/l/passwd
   :target: https://github.com/bsoyka/passwd/blob/master/LICENSE
   :alt: MIT License
.. image:: https://img.shields.io/badge/documentation-blue
   :target: https://passwd.readthedocs.io/
   :alt: Documentation
.. image:: https://img.shields.io/github/issues/bsoyka/passwd
   :target: https://github.com/bsoyka/passwd/issues
   :alt: GitHub Issues

Assorted utilities for gracefully handling and generating passwords

``passwd`` is available on PyPI_! Just install the module with ``pip``:

.. code:: console
   
   $ pip install passwd

.. _PyPI: https://pypi.org/project/passwd

Contributing
============

Please see the `code of conduct`_ and `contributing guidelines`_ for information on contributing to ``passwd``.

.. _code of conduct: https://github.com/bsoyka/passwd/blob/master/CODE_OF_CONDUCT.md
.. _contributing guidelines: https://github.com/bsoyka/passwd/blob/master/CONTRIBUTING.md